@@ -4,8 +4,8 @@
 
 .onLoad <- function(libname, pkgname)
 {
- cat("Companion package to the book:\n")
- cat("Simulation and Inference for Stochastic Differential Equations With R Examples, Springer NY, (2008)\n")
+# cat("Companion package to the book:\n")
+# cat("Simulation and Inference for Stochastic Differential Equations With R Examples, Springer NY, (2008)\n")
  
  library.dynam("sde", pkgname, libname) 
 }
